@@ -16,8 +16,7 @@
  *
  **********************************************************************/
 
-#ifndef GEOS_OP_OVERLAY_ELEVATIONMATRIX_H
-#define GEOS_OP_OVERLAY_ELEVATIONMATRIX_H
+#pragma once
 
 #include <geos/export.h>
 
@@ -110,4 +109,3 @@ private:
 #pragma warning(pop)
 #endif
 
-#endif // ndef GEOS_OP_OVERLAY_ELEVATIONMATRIX_H
